Test tables

Back to the first page

Simple table with header

First name | Last name
--- | ---
John | Doe
Jane | Doe

Table with thead, tfoot, and tbody

Header content 1 | Header content 2
--- | ---
Body content 1 | Body content 2
Footer content 1 | Footer content 2

Table with colgroup

Countries | Capitals | Population | Language
--- | --- | --- | ---
USA | Washington, D.C. | 309 million | English
Sweden | Stockholm | 9 million | Swedish

Table with colgroup and col

Lime | Lemon | Orange
--- | --- | ---
Green | Yellow | Orange

Simple table with caption

Awesome caption
Awesome data

Color names and values
Name | HEX | HSLa | RGBa
--- | --- | --- | ---
Teal | `#51F6F6` | `hsla(180, 90%, 64%, 1)` | `rgba(81, 246, 246, 1)`
Goldenrod | `#F6BC57` | `hsla(38, 90%, 65%, 1)` | `rgba(246, 188, 87, 1)`